<?php
/**
 * Copyright (C) 2019 Leipzig University Library
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @author  Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 */
namespace fid\Service\DataTransferObject;

use Symfony\Component\Serializer\Annotation\Groups;

class Address
{
    /**
     * @var      string|null
     * @Groups({
     *     "user:details:response",
     *     "user:creation:response",
     *     "user:update:request",
     *     "user:update:response",
     * })
     */
    protected $id;

    /**
     * @var User|null
     */
    protected $user;

    /**
     * @var      string|null
     * @Groups({
     *     "user:details:response",
     *     "user:creation:response",
     *     "user:creation:request",
     *     "user:update:request",
     *     "user:update:response"
     * })
     */
    protected $line1;

    /**
     * @var      string|null
     * @Groups({
     *     "user:details:response",
     *     "user:creation:response",
     *     "user:creation:request",
     *     "user:update:request",
     *     "user:update:response"
     * })
     */
    protected $line2;

    /**
     * @var      string|null
     * @Groups({
     *     "user:details:response",
     *     "user:creation:response",
     *     "user:creation:request",
     *     "user:update:request",
     *     "user:update:response"
     * })
     */
    protected $zip;

    /**
     * @var      string|null
     * @Groups({
     *     "user:details:response",
     *     "user:creation:response",
     *     "user:creation:request",
     *     "user:update:request",
     *     "user:update:response"
     * })
     */
    protected $city;

    /**
     * @var      string|null
     * @Groups({
     *     "user:details:response",
     *     "user:creation:response",
     *     "user:creation:request",
     *     "user:update:request",
     *     "user:update:response"
     * })
     */
    protected $country;

    /**
     * @return string|null
     */
    public function getId(): ?string
    {
        return $this->id;
    }

    /**
     * @param string|null $id
     */
    public function setId(?string $id): void
    {
        $this->id = $id;
    }

    /**
     * @return User|null
     */
    public function getUser(): ?User
    {
        return $this->user;
    }

    /**
     * @param User|null $user
     */
    public function setUser(?User $user): void
    {
        $this->user = $user;
    }

    /**
     * @return string|null
     */
    public function getLine1(): ?string
    {
        return $this->line1;
    }

    /**
     * @param string|null $line1
     */
    public function setLine1(?string $line1): void
    {
        $this->line1 = $line1;
    }

    /**
     * @return string|null
     */
    public function getLine2(): ?string
    {
        return $this->line2;
    }

    /**
     * @param string|null $line2
     */
    public function setLine2(?string $line2): void
    {
        $this->line2 = $line2;
    }

    /**
     * @return string|null
     */
    public function getZip(): ?string
    {
        return $this->zip;
    }

    /**
     * @param string|null $zip
     */
    public function setZip(?string $zip): void
    {
        $this->zip = $zip;
    }

    /**
     * @return string|null
     */
    public function getCity(): ?string
    {
        return $this->city;
    }

    /**
     * @param string|null $city
     */
    public function setCity(?string $city): void
    {
        $this->city = $city;
    }

    /**
     * @return string|null
     */
    public function getCountry(): ?string
    {
        return $this->country;
    }

    /**
     * @param string|null $country
     */
    public function setCountry(?string $country): void
    {
        $this->country = $country;
    }

    public function __toString()
    {
        return $this->id . ': ' . $this->line1 . ' ' . $this->line2 . '; ' . $this->zip . ' ' . $this->city . '; ' . $this->country;
    }

    public function isCompleteAddress() : bool
    {
        return strlen($this->line1) > 0
            && strlen($this->zip) > 0
            && strlen($this->city) > 0;
    }
}
