<?php
/**
 * Copyright (C) 2020 Leipzig University Library
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @author  Alexander Purr <purr@ub.uni-leipzig.de>
 * @license http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 */
namespace fid\Validator;

use Zend\Validator\AbstractValidator;

class SubitoPartialCopyPageBounds extends AbstractValidator
{
    use SubitoPartialCopyPageRangeValidatorTrait;

    public const PAGE_BOUNDS = 'subitoPartialCopyPageBounds';

    // Available validator options.
    protected $options = [
        'numberPages' => null
    ];

    protected $messageTemplates = [
        self::PAGE_BOUNDS => "acquisition_error_page_bounds",
    ];

    public function isValid($value)
    {
        if ($this->options['numberPages'] == null) {
            return false;
        }
        $this->extractPages($value);

        if (($this->pageEnd > $this->options['numberPages']) || ($this->pageStart < 1)) {
            $this->error(self::PAGE_BOUNDS);
            return false;
        } else {
            return true;
        }
    }
}
