<?php
/**
 * FID Client User Groups view helper
 *
 * PHP version 7
 *
 * Copyright (C) Leipzig University Library 2019.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  View_Helpers
 * @author   Demian Katz <demian.katz@villanova.edu>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development Wiki
 */
namespace fid\View\Helper\Root;

use VuFind\I18n\Translator\TranslatorAwareTrait;
use Zend\View\Helper\AbstractHelper;

/**
 * FID Client User Groups view helper
 *
 * @category VuFind
 * @package  View_Helpers
 * @author   Dorian Merz <merz@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development Wiki
 */
class UserGroups extends AbstractHelper
{
    use TranslatorAwareTrait;

    protected $displayRoles;

    protected $rolePriority;

    protected $displayOrder;

    private $groups;

    public function __construct($fidConfig)
    {
        $this->displayRoles = $fidConfig->UserProfile['role_display']->toArray() ?? [];
        foreach ($fidConfig->UserProfile['role_display_priority'] ?? [] as $prios) {
            $roles = explode('>', $prios);
            while (count($roles) > 1) {
                $current = array_pop($roles);
                if (!empty($roles)) {
                    $this->rolePriority[$current] = $roles;
                }
            }
        }
        $this->displayOrder = explode('>', $fidConfig->UserProfile['role_display_order'] ?? '');
    }

    public function __invoke($permissions)
    {
        $this->groups['requested'] =
        $this->groups['granted'] = array_fill_keys($this->displayOrder, null);
        foreach ($permissions as $permission => $status) {
            // $status is in ['granted','requested']
            if (in_array($permission, $this->displayRoles)) {
                $this->groups[$status][$permission] =
                    $this->translate('fid::label_access_level_' . $permission);
            }
        }
        foreach (['granted','requested'] as $status) {
            $groups = array_filter($this->groups[$status]);
            foreach ((array)$this->rolePriority as $role => $prioritized) {
                if (isset($groups[$role])) {
                    foreach ($prioritized as $prio) {
                        if (isset($groups[$prio])) {
                            unset($groups[$role]);
                            break;
                        }
                    }
                }
            }
            $this->groups[$status] = $groups;
        }
        return $this;
    }

    public function granted()
    {
        return !empty($this->groups['granted']) ? implode("; ", $this->groups['granted']) : null;
    }

    public function requested()
    {
        return !empty($this->groups['requested']) ? implode('; ', $this->groups['requested']) : null;
    }
}
