<?php
/**
 * Copyright (C) 2019 Leipzig University Library
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @author  Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 */
namespace fid\VuFind\Auth;

use fid\Service\Client;
use fid\Service\ClientException;
use fid\Service\UserNotAuthorizedException;

class ILSAuthenticator
{
    /**
     * @var Client
     */
    protected $client;

    public function __construct(Client $client)
    {
        $this->client = $client;
    }

    /**
     * @return array|null
     * @throws ClientException
     * @throws UserNotAuthorizedException
     */
    public function newCatalogLogin()
    {
        return $this->storedCatalogLogin();
    }

    /**
     * @return array|null
     * @throws ClientException
     * @throws UserNotAuthorizedException
     */
    public function storedCatalogLogin()
    {
        try {
            $user = $this->client->requestUserDetails();
            $libs = $this->client->requestLibraryList();
        } catch (ClientException $e) {
            if ($e->getCode() == '401') {
                return null;
            } else {
                throw $e;
            }
        }
        if (!$user) {
            return null;
        }

        $data = [
            'permissions' => $user->getPermissions(),
            'username'    => $user->getUsername(),
            'firstname'   => $user->getFirstname(),
            'lastname'    => $user->getLastname(),
            'email'       => $user->getUsername(),
            'user'        => $user,
            'libs'        => $libs,
        ];

        foreach ($user->getAddresses() as $index => $address) {
            $data['address' . ($index + 1)] = implode(
                ", ",
                array_filter(
                    [
                    $address->getLine1(),
                    $address->getLine2(),
                    trim("{$address->getZip()} {$address->getCity()}"),
                    $address->getCountry()
                    ]
                )
            );
        }

        return $data;
    }
}
