<?php
/**
 * Copyright (C) 2019 Leipzig University Library
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @author  Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 */
namespace fid\VuFind\Db\Row;

use fid\Service\Client;
use fid\Service\ClientException;
use VuFind\Db\Row\User as BaseUser;

class User extends BaseUser
{
    /**
     * @var Client
     */
    protected $client;

    public function setClient(Client $client)
    {
        $this->client = $client;
    }

    /**
     * @param string $offset
     *
     * @return mixed|string|null
     * @throws ClientException
     */
    public function offsetGet($offset)
    {
        return $this->readUserFields($offset) ?: parent::offsetGet($offset);
    }

    public function __get($name)
    {
        return $this->readUserFields($name) ?: parent::__get($name);
    }

    protected function readUserFields($offset)
    {
        $user = $this->client->requestUserDetails();

        switch ($offset) {
        case 'firstname':
            return $user->getFirstname();
        case 'lastname':
            return $user->getLastname();
        case 'email':
            return $user->getUsername();
        }

        return false;
    }
}
