<?php
/**
 * Copyright (C) 2019 Leipzig University Library
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * @author  Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license http://opensource.org/licenses/gpl-2.0.php GNU GPLv2
 */
namespace fid\VuFind\ILS;

use fid\Service\Client;
use fid\Service\ClientException;
use VuFind\Exception\ILS as ILSException;
use VuFind\ILS\Driver\AbstractBase;

class Fid extends AbstractBase
{
    /**
     * @var Client
     */
    protected $client;

    public function __construct(Client $client)
    {
        $this->client = $client;
    }

    public function init()
    {
    }

    /**
     * @return array|null
     * @throws ClientException
     */
    public function patronLogin(): ?array
    {
        $user = $this->client->requestUserDetails();

        if (!$user) {
            return null;
        }

        return ['id' => $user->getId()];
    }

    public function getStatus($id)
    {
        throw new ILSException('Method not available');
    }

    public function getStatuses($ids)
    {
        throw new ILSException('Method not available');
    }

    public function getHolding($id, array $patron = null)
    {
        throw new ILSException('Method not available');
    }

    public function getPurchaseHistory($id)
    {
        throw new ILSException('Method not available');
    }

    public function getMyProfile($patron)
    {
        return $patron;
    }
}
